Clojure only.

hyperphor.ellum.generated


bag=clj

(bag= b1 & bs)

Returns true if the collections contain the same elements regardless of order.

Returns true if the collections contain the same elements regardless of order.
sourceraw docstring

powersetclj

(powerset coll)

Generate the powerset of a collection.

Generate the powerset of a collection.
sourceraw docstring

tripleclj

(triple s)

Repeats string s three times, separated by commas.

Repeats string s three times, separated by commas.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries