hyperphor.ellum.schema


array-schemaclj

(array-schema item-schema)

Build a JSON Schema array definition.

Build a JSON Schema array definition.
sourceraw docstring

boolean-schemaclj

(boolean-schema)
(boolean-schema description)
source

coerceclj

(coerce schema value)

Coerce a value to match a JSON schema spec. Currently validates types and does basic coercions (string->number, etc.). Returns the coerced value or throws on invalid input.

Coerce a value to match a JSON schema spec.
Currently validates types and does basic coercions (string->number, etc.).
Returns the coerced value or throws on invalid input.
sourceraw docstring

number-schemaclj

(number-schema)
(number-schema description)
source

object-schemaclj

(object-schema properties & {:keys [required]})

Build a JSON Schema object definition.

Build a JSON Schema object definition.
sourceraw docstring

openai-json-schema-formatclj

(openai-json-schema-format name schema & {:keys [strict] :or {strict true}})

Build an OpenAI response_format for structured JSON output.

Build an OpenAI response_format for structured JSON output.
sourceraw docstring

string-schemaclj

(string-schema)
(string-schema description)
(string-schema description enum-vals)
source

validate-requiredclj

(validate-required schema value)

Check that all required fields are present in a map. Returns nil or throws.

Check that all required fields are present in a map. Returns nil or throws.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries