(bag= b1 & bs)Returns true if the collections contain the same elements regardless of order.
Returns true if the collections contain the same elements regardless of order.
(powerset coll)Generate the powerset of a collection.
Generate the powerset of a collection.
(triple s)Repeats string s three times, separated by commas.
Repeats string s three times, separated by commas.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |