(array-schema item-schema)Build a JSON Schema array definition.
Build a JSON Schema array definition.
(coerce schema value)Coerce a value to match a JSON schema spec. Currently validates types and does basic coercions (string->number, etc.). Returns the coerced value or throws on invalid input.
Coerce a value to match a JSON schema spec. Currently validates types and does basic coercions (string->number, etc.). Returns the coerced value or throws on invalid input.
(object-schema properties & {:keys [required]})Build a JSON Schema object definition.
Build a JSON Schema object definition.
(openai-json-schema-format name schema & {:keys [strict] :or {strict true}})Build an OpenAI response_format for structured JSON output.
Build an OpenAI response_format for structured JSON output.
(string-schema)(string-schema description)(string-schema description enum-vals)(validate-required schema value)Check that all required fields are present in a map. Returns nil or throws.
Check that all required fields are present in a map. Returns nil or throws.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |